@@ -10,6 +10,7 @@ import sqlite3
 
 from decentra_network.accounts.account import Account
 from decentra_network.config import TEMP_ACCOUNTS_PATH
+from decentra_network.lib.cache import Cache
 from decentra_network.lib.config_system import get_config
 
 
@@ -22,12 +23,19 @@ def GetAccounts(custom_TEMP_ACCOUNTS_PATH=None):
                               if custom_TEMP_ACCOUNTS_PATH is None else
                               custom_TEMP_ACCOUNTS_PATH)
 
-    os.chdir(get_config()["main_folder"])
-    conn = sqlite3.connect(the_TEMP_ACCOUNTS_PATH, check_same_thread=False)
-    c = conn.cursor()
-    c.execute(
-        """CREATE TABLE IF NOT EXISTS account_list (address text, sequance_number integer, balance integer)"""
-    )
-    conn.commit()
+    the_cache = Cache.get(the_TEMP_ACCOUNTS_PATH)
+    the_cache_2 = Cache.get(f"{the_TEMP_ACCOUNTS_PATH}_conn")
+    if the_cache is None or the_cache_2 is None:
+        os.chdir(get_config()["main_folder"])
+        conn = sqlite3.connect(the_TEMP_ACCOUNTS_PATH, check_same_thread=False)
+        c = conn.cursor()
+        c.execute(
+            """CREATE TABLE IF NOT EXISTS account_list (address text, sequance_number integer, balance integer)"""
+        )
+        conn.commit()
 
-    return c
+        Cache.save(the_TEMP_ACCOUNTS_PATH, c)
+        Cache.save(f"{the_TEMP_ACCOUNTS_PATH}_conn", conn)
+        return c
+    else:
+        return the_cache
